[−][src]Enum lpc55_pac::i2c0::stat::MONACTIVE_A
pub enum MONACTIVE_A {
INACTIVE,
ACTIVE,
}Monitor Active flag. Indicates when the Monitor function considers the I 2C bus to be active. Active is defined here as when some Master is on the bus: a bus Start has occurred more recently than a bus Stop.
Value on reset: 0
Variants
0: Inactive. The Monitor function considers the I2C bus to be inactive.
1: Active. The Monitor function considers the I2C bus to be active.