[−][src]Enum lpc55_pac::i2c0::stat::SLVDESEL_A
pub enum SLVDESEL_A {
NOT_DESELECTED,
DESELECTED,
}Slave Deselected flag. This flag will cause an interrupt when set if enabled via INTENSET. This flag can be cleared by writing a 1 to this bit.
Value on reset: 0
Variants
0: Not deselected. The Slave function has not become deselected. This does not mean that it is currently selected. That information can be found in the SLVSEL flag.
1: Deselected. The Slave function has become deselected. This is specifically caused by the SLVSEL flag changing from 1 to 0. See the description of SLVSEL for details on when that event occurs.